--[[$Id: Options.lua 30626 2007-03-21 02:58:07Z eternally777 $]]

---------------------------------
--       Local Variables       --
---------------------------------
local L = AceLibrary('AceLocale-2.2'):new('GetInLine')
local GetInLine = getfenv(0).GetInLine

local function CheckCase(playerName)
	return playerName:sub(1, 1):upper() .. playerName:sub(2):lower()
end

--[[ ---------------------------- ]]

local SetAdd = function(playerName)
	playerName = CheckCase(playerName)
	if GetInLine:AddPlayer(playerName) then
		GetInLine:Print(L['You have added %s to the wait list.']:format(playerName))
	end
end

local ValidateName = function(playerName)
	return playerName:find('^%w+$')
end

--[[ ---------------------------- ]]

local SetRem = function(playerName)
	playerName = CheckCase(playerName)
	if GetInLine:RemovePlayer(playerName) then
		GetInLine:Print(L['You have removed %s from the wait list.']:format(playerName))
	end
end

--[[ ---------------------------- ]]

local GetWhispers = function()
	return GetInLine.db.profile.raidOnlyWhispers
end

local SetWhispers = function()
	GetInLine.db.profile.raidOnlyWhispers = not GetInLine.db.profile.raidOnlyWhispers
end

--[[ ---------------------------- ]]

local GetClearOnExit = function()
	return GetInLine.db.profile.clearOnExit
end

local SetClearOnExit = function()
	GetInLine.db.profile.clearOnExit = not GetInLine.db.profile.clearOnExit
end

--[[ ---------------------------- ]]

local GetAdditions = function()
	return GetInLine.db.profile.notifications.additions
end

local SetAdditions = function()
	GetInLine.db.profile.notifications.additions = not GetInLine.db.profile.notifications.additions
end

--[[ ---------------------------- ]]

local GetRemovals = function()
	return GetInLine.db.profile.notifications.removals
end

local SetRemovals = function()
	GetInLine.db.profile.notifications.removals = not GetInLine.db.profile.notifications.removals
end

--[[ ---------------------------- ]]

local GetRequests = function()
	return GetInLine.db.profile.notifications.listRequest
end

local SetRequests = function()
	GetInLine.db.profile.notifications.listRequest = not GetInLine.db.profile.notifications.listRequest
end

--[[ ---------------------------- ]]

local GetSent = function()
	return GetInLine.db.profile.notifications.listSent
end

local SetSent = function()
	GetInLine.db.profile.notifications.listSent = not GetInLine.db.profile.notifications.listSent
end

--[[ ---------------------------- ]]

local RaidAnnounceDisabled = function()
	return GetNumRaidMembers() > 0
end

local RaidAnnounce = function()
	GetInLine:AnnounceList("RAID")
end

--[[ ---------------------------- ]]

local GuildAnnounce = function()
	GetInLine:AnnounceList("GUILD")
end

--[[ ---------------------------- ]]

local optionsTable = {
	type = 'group',
	args = {
		[ L['Whispers'] ] = {
			name = L['Raid-Only Whispers'], type = 'toggle', order = 1,
			desc = L['Only accept whisper commands while in a raid.'],
			get = GetWhispers, set = SetWhispers
		},
		[ L['ClearOnExit'] ] = {
			name = L['Clear On Exit'], type = 'toggle', order = 2,
			desc = L['Clear the wait list upon leaving a raid.'],
			get = GetClearOnExit, set = SetClearOnExit
		},
		[ L['Purge'] ] = {
			name = L['Purge the List'], type = 'execute', order = 3,
			desc = L['Manually purge the wait list.'],
			func = GetInLine.PurgeList
		},
		
		{
			type = 'header', order = 10
		},
		
		[ L['Add'] ] = {
			name = L['Add Player'], type = 'text', order = 11,
			desc = L['Add a player to the wait list.'],
			usage = '<'..NAME..'>', get = false,
			set = SetAdd, validate = ValidateName
		},
		[ L['Rem'] ] = {
			name = L['Remove Player'], type = 'text', order = 12,
			desc = L['Remove a player from the wait list.'],
			usage = '<'..NAME..'>', get = false,
			set = SetRem, validate = ValidateName
		},
		
		{
			type = 'header', order = 20
		},
		
		[ L['Announce'] ] = {
			name = L['Announce'], type = 'group', order = 21,
			desc = L['Announce the current list to a channel.'],
			args = {
				[CHAT_MSG_RAID] = {
					name = L['Raid Chat'], type = 'execute',
					desc = L['Announce the list in Raid chat.'],
					disabled = RaidAnnounceDisabled, func = RaidAnnounce
				},
				[CHAT_MSG_GUILD] = {
					name = L['Guild Chat'], type = 'execute',
					desc = L['Announce the list in Guild chat.'],
					func = GuildAnnounce
				}
			}
		},
		[ L['Notifications'] ] = {
			name = L['Notifications'], type = 'group', order = 22,
			desc = L['Controls to suppress whispers sent and received by this mod.'],
			args = {
				[ L['Additions'] ] = {
					name = L['Additions to the List'], type = 'toggle', order = 1,
					desc = L['Notify me when a player is added to the waiting list.'],
					get = GetAdditions, set = SetAdditions
				},
				[ L['Removals'] ] = {
					name = L['Removals from the List'], type = 'toggle', order = 2,
					desc = L['Notify me when a player is removed from the waiting list.'],
					get = GetRemovals, set = SetRemovals
				},
				[ L['List'] ] = {
					name = L['List Notifications'], type = 'group', order = 3,
					desc = L['Notifications regarding list requests.'],
					args = {
						[ L['Requests'] ] = {
							name = L['Requests'], type = 'toggle', order = 1,
							desc = L['Notify me when a player requests to view the current list.'],
							get = GetRequests, set = SetRequests
						},
						[ L['Sent'] ] = {
							name = L['Sent'], type = 'toggle', order = 2,
							desc = L['Notify me when the current waiting list has been sent to a player.'],
							get = GetSent, set = SetSent
						}
					}
				}
			}
		}
	}
}

GetInLine:RegisterChatCommand({ '/GiL', '/GetInLine' }, optionsTable)
GetInLine.OnMenuRequest = optionsTable